==> haskell-pandoc-server-0.1.0.6-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-server
version:              0.1.0.6
visibility:           public
id:                   pandoc-server-0.1.0.6-EpgwqjSqjurESKyKpM732z
key:                  pandoc-server-0.1.0.6-EpgwqjSqjurESKyKpM732z
license:              GPL-2.0-or-later
copyright:            (c) 2006-2022 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Pandoc document conversion as an HTTP servant-server
description:
    Pandoc-server provides pandoc'\''s document conversion functions
    in an HTTP server.

category:             Text
abi:                  a7b017c2a40ae95687805d4f3306e978
exposed:              True
exposed-modules:      Text.Pandoc.Server
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-server
hs-libraries:         HSpandoc-server-0.1.0.6-EpgwqjSqjurESKyKpM732z
depends:
    aeson-2.1.2.1-CoFGCad0PesDH4XC5ctCv4 base-4.17.2.1
    base64-bytestring-1.2.1.0-H7PD9x3a1R75H5UmP3m5CT
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd
    doctemplates-0.11.0.1-DcZqx3UNBEhGKyqiW3oFsw
    pandoc-3.2.1-1Rh0aYaMREzBMDiuleXryp
    pandoc-types-1.23.1-7gWDUsUafgnGN4MZXQBBdX
    servant-server-0.20.3.0-F70hw924dVX11PFVE3P8JQ
    skylighting-0.14.2-A6jM5G7lF8lFr2Jm627wge text-2.0.2
    unicode-collation-0.1.3.6-BRc5evUvQsKFS8gF7jC8bV
    wai-3.2.4-CKkA8Aq5NeD7z1ZAcTjQU2
    wai-cors-0.2.7-2JyU87X2T3n2cpb6MUI29L

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-server/html/pandoc-server.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-server-0.1.0.6-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-server
version:              0.1.0.6
visibility:           public
id:                   pandoc-server-0.1.0.6-GeABGdFapLV6PK9TYLO7c8
key:                  pandoc-server-0.1.0.6-GeABGdFapLV6PK9TYLO7c8
license:              GPL-2.0-or-later
copyright:            (c) 2006-2022 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Pandoc document conversion as an HTTP servant-server
description:
    Pandoc-server provides pandoc'\''s document conversion functions
    in an HTTP server.

category:             Text
abi:                  93fde5ecf5b2cce5cca35f077c5c73eb
exposed:              True
exposed-modules:      Text.Pandoc.Server
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-server
hs-libraries:         HSpandoc-server-0.1.0.6-GeABGdFapLV6PK9TYLO7c8
depends:
    aeson-2.1.2.1-CoFGCad0PesDH4XC5ctCv4 base-4.17.2.1
    base64-bytestring-1.2.1.0-H7PD9x3a1R75H5UmP3m5CT
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd
    doctemplates-0.11.0.1-DcZqx3UNBEhGKyqiW3oFsw
    pandoc-3.2.1-HFKbuybiPXO5FqL4kf3ETq
    pandoc-types-1.23.1-7gWDUsUafgnGN4MZXQBBdX
    servant-server-0.20.3.0-J0ZXuDzr9MDA2YTYzjqU4j
    skylighting-0.14.2-A6jM5G7lF8lFr2Jm627wge text-2.0.2
    unicode-collation-0.1.3.6-BRc5evUvQsKFS8gF7jC8bV
    wai-3.2.4-CKkA8Aq5NeD7z1ZAcTjQU2
    wai-cors-0.2.7-2JyU87X2T3n2cpb6MUI29L

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-server/html/pandoc-server.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
